@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,10 +20,10 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation as gac_operation  # type: ignore
@@ -33,8 +31,7 @@ from google.api_core import operation_async  # type: ignore
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import application
 from google.cloud.appengine_admin_v1.types import operation as ga_operation
-from google.protobuf import duration_pb2 as duration  # type: ignore
-
+from google.protobuf import duration_pb2  # type: ignore
 from .transports.base import ApplicationsTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import ApplicationsGrpcAsyncIOTransport
 from .client import ApplicationsClient
@@ -54,20 +51,16 @@ class ApplicationsAsyncClient:
     parse_common_billing_account_path = staticmethod(
         ApplicationsClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(ApplicationsClient.common_folder_path)
     parse_common_folder_path = staticmethod(ApplicationsClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(ApplicationsClient.common_organization_path)
     parse_common_organization_path = staticmethod(
         ApplicationsClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(ApplicationsClient.common_project_path)
     parse_common_project_path = staticmethod(
         ApplicationsClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(ApplicationsClient.common_location_path)
     parse_common_location_path = staticmethod(
         ApplicationsClient.parse_common_location_path
@@ -75,7 +68,8 @@ class ApplicationsAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -90,7 +84,7 @@ class ApplicationsAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -107,7 +101,7 @@ class ApplicationsAsyncClient:
 
     @property
     def transport(self) -> ApplicationsTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             ApplicationsTransport: The transport used by the client instance.
@@ -121,12 +115,12 @@ class ApplicationsAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, ApplicationsTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the applications client.
+        """Instantiates the applications client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -158,7 +152,6 @@ class ApplicationsAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = ApplicationsClient(
             credentials=credentials,
             transport=transport,
@@ -180,7 +173,6 @@ class ApplicationsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.GetApplicationRequest`):
                 The request object. Request message for
                 `Applications.GetApplication`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -195,7 +187,6 @@ class ApplicationsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.GetApplicationRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -242,7 +233,6 @@ class ApplicationsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.CreateApplicationRequest`):
                 The request object. Request message for
                 `Applications.CreateApplication`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -258,7 +248,6 @@ class ApplicationsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.CreateApplicationRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -303,7 +292,6 @@ class ApplicationsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.UpdateApplicationRequest`):
                 The request object. Request message for
                 `Applications.UpdateApplication`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -319,7 +307,6 @@ class ApplicationsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.UpdateApplicationRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -374,7 +361,6 @@ class ApplicationsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.RepairApplicationRequest`):
                 The request object. Request message for
                 'Applications.RepairApplication'.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -390,7 +376,6 @@ class ApplicationsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.RepairApplicationRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
