@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -37,8 +35,7 @@ from google.api_core import operation_async  # type: ignore
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import application
 from google.cloud.appengine_admin_v1.types import operation as ga_operation
-from google.protobuf import duration_pb2 as duration  # type: ignore
-
+from google.protobuf import duration_pb2  # type: ignore
 from .transports.base import ApplicationsTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import ApplicationsGrpcTransport
 from .transports.grpc_asyncio import ApplicationsGrpcAsyncIOTransport
@@ -57,7 +54,7 @@ class ApplicationsClientMeta(type):
     _transport_registry["grpc_asyncio"] = ApplicationsGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[ApplicationsTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -80,7 +77,8 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -114,7 +112,8 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -131,7 +130,7 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -150,16 +149,17 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
     @property
     def transport(self) -> ApplicationsTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            ApplicationsTransport: The transport used by the client instance.
+            ApplicationsTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -172,7 +172,7 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -183,7 +183,7 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -194,7 +194,7 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -205,7 +205,7 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -219,12 +219,12 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ApplicationsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the applications client.
+        """Instantiates the applications client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -279,9 +279,10 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -293,12 +294,14 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -313,8 +316,8 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -343,7 +346,6 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
             request (google.cloud.appengine_admin_v1.types.GetApplicationRequest):
                 The request object. Request message for
                 `Applications.GetApplication`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -358,7 +360,6 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.GetApplicationRequest.
         # There's no risk of modifying the input as we've already verified
@@ -406,7 +407,6 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
             request (google.cloud.appengine_admin_v1.types.CreateApplicationRequest):
                 The request object. Request message for
                 `Applications.CreateApplication`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -422,7 +422,6 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.CreateApplicationRequest.
         # There's no risk of modifying the input as we've already verified
@@ -468,7 +467,6 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
             request (google.cloud.appengine_admin_v1.types.UpdateApplicationRequest):
                 The request object. Request message for
                 `Applications.UpdateApplication`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -484,7 +482,6 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.UpdateApplicationRequest.
         # There's no risk of modifying the input as we've already verified
@@ -540,7 +537,6 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
             request (google.cloud.appengine_admin_v1.types.RepairApplicationRequest):
                 The request object. Request message for
                 'Applications.RepairApplication'.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -556,7 +552,6 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.RepairApplicationRequest.
         # There's no risk of modifying the input as we've already verified
