@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.api_core import operations_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import application
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import ApplicationsTransport, DEFAULT_CLIENT_INFO
 from .grpc import ApplicationsGrpcTransport
 
@@ -56,7 +53,7 @@ class ApplicationsGrpcAsyncIOTransport(ApplicationsTransport):
     def create_channel(
         cls,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -83,13 +80,15 @@ class ApplicationsGrpcAsyncIOTransport(ApplicationsTransport):
         Returns:
             aio.Channel: A gRPC AsyncIO channel object.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -97,7 +96,7 @@ class ApplicationsGrpcAsyncIOTransport(ApplicationsTransport):
         self,
         *,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
@@ -111,7 +110,8 @@ class ApplicationsGrpcAsyncIOTransport(ApplicationsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -170,7 +170,6 @@ class ApplicationsGrpcAsyncIOTransport(ApplicationsTransport):
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-
         else:
             if api_mtls_endpoint:
                 host = api_mtls_endpoint
@@ -277,7 +276,7 @@ class ApplicationsGrpcAsyncIOTransport(ApplicationsTransport):
     def create_application(
         self,
     ) -> Callable[
-        [appengine.CreateApplicationRequest], Awaitable[operations.Operation]
+        [appengine.CreateApplicationRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the create application method over gRPC.
 
@@ -307,7 +306,7 @@ class ApplicationsGrpcAsyncIOTransport(ApplicationsTransport):
             self._stubs["create_application"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.Applications/CreateApplication",
                 request_serializer=appengine.CreateApplicationRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_application"]
 
@@ -315,7 +314,7 @@ class ApplicationsGrpcAsyncIOTransport(ApplicationsTransport):
     def update_application(
         self,
     ) -> Callable[
-        [appengine.UpdateApplicationRequest], Awaitable[operations.Operation]
+        [appengine.UpdateApplicationRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the update application method over gRPC.
 
@@ -341,7 +340,7 @@ class ApplicationsGrpcAsyncIOTransport(ApplicationsTransport):
             self._stubs["update_application"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.Applications/UpdateApplication",
                 request_serializer=appengine.UpdateApplicationRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["update_application"]
 
@@ -349,7 +348,7 @@ class ApplicationsGrpcAsyncIOTransport(ApplicationsTransport):
     def repair_application(
         self,
     ) -> Callable[
-        [appengine.RepairApplicationRequest], Awaitable[operations.Operation]
+        [appengine.RepairApplicationRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the repair application method over gRPC.
 
@@ -379,7 +378,7 @@ class ApplicationsGrpcAsyncIOTransport(ApplicationsTransport):
             self._stubs["repair_application"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.Applications/RepairApplication",
                 request_serializer=appengine.RepairApplicationRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["repair_application"]
 
