@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -38,8 +36,7 @@ from google.cloud.appengine_admin_v1.services.domain_mappings import pagers
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import domain_mapping
 from google.cloud.appengine_admin_v1.types import operation as ga_operation
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 from .transports.base import DomainMappingsTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import DomainMappingsGrpcTransport
 from .transports.grpc_asyncio import DomainMappingsGrpcAsyncIOTransport
@@ -60,7 +57,7 @@ class DomainMappingsClientMeta(type):
     _transport_registry["grpc_asyncio"] = DomainMappingsGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[DomainMappingsTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -83,7 +80,8 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -117,7 +115,8 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -134,7 +133,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -153,16 +152,17 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
     @property
     def transport(self) -> DomainMappingsTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            DomainMappingsTransport: The transport used by the client instance.
+            DomainMappingsTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -175,7 +175,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -186,7 +186,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -197,7 +197,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -208,7 +208,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -222,12 +222,12 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, DomainMappingsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the domain mappings client.
+        """Instantiates the domain mappings client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -282,9 +282,10 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -296,12 +297,14 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -316,8 +319,8 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -346,7 +349,6 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
             request (google.cloud.appengine_admin_v1.types.ListDomainMappingsRequest):
                 The request object. Request message for
                 `DomainMappings.ListDomainMappings`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -362,7 +364,6 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.ListDomainMappingsRequest.
         # There's no risk of modifying the input as we've already verified
@@ -406,7 +407,6 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
             request (google.cloud.appengine_admin_v1.types.GetDomainMappingRequest):
                 The request object. Request message for
                 `DomainMappings.GetDomainMapping`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -420,7 +420,6 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.GetDomainMappingRequest.
         # There's no risk of modifying the input as we've already verified
@@ -461,7 +460,6 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
             request (google.cloud.appengine_admin_v1.types.CreateDomainMappingRequest):
                 The request object. Request message for
                 `DomainMappings.CreateDomainMapping`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -478,7 +476,6 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.CreateDomainMappingRequest.
         # There's no risk of modifying the input as we've already verified
@@ -528,7 +525,6 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
             request (google.cloud.appengine_admin_v1.types.UpdateDomainMappingRequest):
                 The request object. Request message for
                 `DomainMappings.UpdateDomainMapping`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -545,7 +541,6 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.UpdateDomainMappingRequest.
         # There's no risk of modifying the input as we've already verified
@@ -593,7 +588,6 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
             request (google.cloud.appengine_admin_v1.types.DeleteDomainMappingRequest):
                 The request object. Request message for
                 `DomainMappings.DeleteDomainMapping`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -620,7 +614,6 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.DeleteDomainMappingRequest.
         # There's no risk of modifying the input as we've already verified
@@ -645,7 +638,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
         response = gac_operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=ga_operation.OperationMetadataV1,
         )
 
