@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -35,7 +33,6 @@ from google.oauth2 import service_account  # type: ignore
 from google.cloud.appengine_admin_v1.services.firewall import pagers
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import firewall
-
 from .transports.base import FirewallTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import FirewallGrpcTransport
 from .transports.grpc_asyncio import FirewallGrpcAsyncIOTransport
@@ -54,7 +51,7 @@ class FirewallClientMeta(type):
     _transport_registry["grpc_asyncio"] = FirewallGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[FirewallTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -88,7 +85,8 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -122,7 +120,8 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -139,7 +138,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -158,16 +157,17 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     @property
     def transport(self) -> FirewallTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            FirewallTransport: The transport used by the client instance.
+            FirewallTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -180,7 +180,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -191,7 +191,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -202,7 +202,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -213,7 +213,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -227,12 +227,12 @@ class FirewallClient(metaclass=FirewallClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, FirewallTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the firewall client.
+        """Instantiates the firewall client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -287,9 +287,10 @@ class FirewallClient(metaclass=FirewallClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -301,12 +302,14 @@ class FirewallClient(metaclass=FirewallClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -321,8 +324,8 @@ class FirewallClient(metaclass=FirewallClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -351,7 +354,6 @@ class FirewallClient(metaclass=FirewallClientMeta):
             request (google.cloud.appengine_admin_v1.types.ListIngressRulesRequest):
                 The request object. Request message for
                 `Firewall.ListIngressRules`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -367,7 +369,6 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.ListIngressRulesRequest.
         # There's no risk of modifying the input as we've already verified
@@ -417,7 +418,6 @@ class FirewallClient(metaclass=FirewallClientMeta):
             request (google.cloud.appengine_admin_v1.types.BatchUpdateIngressRulesRequest):
                 The request object. Request message for
                 `Firewall.BatchUpdateIngressRules`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -429,7 +429,6 @@ class FirewallClient(metaclass=FirewallClientMeta):
                 Response message for Firewall.UpdateAllIngressRules.
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.BatchUpdateIngressRulesRequest.
         # There's no risk of modifying the input as we've already verified
@@ -469,7 +468,6 @@ class FirewallClient(metaclass=FirewallClientMeta):
             request (google.cloud.appengine_admin_v1.types.CreateIngressRuleRequest):
                 The request object. Request message for
                 `Firewall.CreateIngressRule`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -485,7 +483,6 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.CreateIngressRuleRequest.
         # There's no risk of modifying the input as we've already verified
@@ -523,7 +520,6 @@ class FirewallClient(metaclass=FirewallClientMeta):
             request (google.cloud.appengine_admin_v1.types.GetIngressRuleRequest):
                 The request object. Request message for
                 `Firewall.GetIngressRule`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -539,7 +535,6 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.GetIngressRuleRequest.
         # There's no risk of modifying the input as we've already verified
@@ -577,7 +572,6 @@ class FirewallClient(metaclass=FirewallClientMeta):
             request (google.cloud.appengine_admin_v1.types.UpdateIngressRuleRequest):
                 The request object. Request message for
                 `Firewall.UpdateIngressRule`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -593,7 +587,6 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.UpdateIngressRuleRequest.
         # There's no risk of modifying the input as we've already verified
@@ -631,7 +624,6 @@ class FirewallClient(metaclass=FirewallClientMeta):
             request (google.cloud.appengine_admin_v1.types.DeleteIngressRuleRequest):
                 The request object. Request message for
                 `Firewall.DeleteIngressRule`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -639,7 +631,6 @@ class FirewallClient(metaclass=FirewallClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.DeleteIngressRuleRequest.
         # There's no risk of modifying the input as we've already verified
