@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,22 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Callable, Dict, Optional, Sequence, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import grpc_helpers  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import firewall
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 from .base import FirewallTransport, DEFAULT_CLIENT_INFO
 
 
@@ -62,7 +59,7 @@ class FirewallGrpcTransport(FirewallTransport):
         self,
         *,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
@@ -76,7 +73,8 @@ class FirewallGrpcTransport(FirewallTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -186,7 +184,7 @@ class FirewallGrpcTransport(FirewallTransport):
     def create_channel(
         cls,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -217,13 +215,15 @@ class FirewallGrpcTransport(FirewallTransport):
             google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -377,7 +377,7 @@ class FirewallGrpcTransport(FirewallTransport):
     @property
     def delete_ingress_rule(
         self,
-    ) -> Callable[[appengine.DeleteIngressRuleRequest], empty.Empty]:
+    ) -> Callable[[appengine.DeleteIngressRuleRequest], empty_pb2.Empty]:
         r"""Return a callable for the delete ingress rule method over gRPC.
 
         Deletes the specified firewall rule.
@@ -396,7 +396,7 @@ class FirewallGrpcTransport(FirewallTransport):
             self._stubs["delete_ingress_rule"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.Firewall/DeleteIngressRule",
                 request_serializer=appengine.DeleteIngressRuleRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_ingress_rule"]
 
