@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,23 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import firewall
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 from .base import FirewallTransport, DEFAULT_CLIENT_INFO
 from .grpc import FirewallGrpcTransport
 
@@ -65,7 +62,7 @@ class FirewallGrpcAsyncIOTransport(FirewallTransport):
     def create_channel(
         cls,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -92,13 +89,15 @@ class FirewallGrpcAsyncIOTransport(FirewallTransport):
         Returns:
             aio.Channel: A gRPC AsyncIO channel object.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -106,7 +105,7 @@ class FirewallGrpcAsyncIOTransport(FirewallTransport):
         self,
         *,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
@@ -120,7 +119,8 @@ class FirewallGrpcAsyncIOTransport(FirewallTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -178,7 +178,6 @@ class FirewallGrpcAsyncIOTransport(FirewallTransport):
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-
         else:
             if api_mtls_endpoint:
                 host = api_mtls_endpoint
@@ -386,7 +385,7 @@ class FirewallGrpcAsyncIOTransport(FirewallTransport):
     @property
     def delete_ingress_rule(
         self,
-    ) -> Callable[[appengine.DeleteIngressRuleRequest], Awaitable[empty.Empty]]:
+    ) -> Callable[[appengine.DeleteIngressRuleRequest], Awaitable[empty_pb2.Empty]]:
         r"""Return a callable for the delete ingress rule method over gRPC.
 
         Deletes the specified firewall rule.
@@ -405,7 +404,7 @@ class FirewallGrpcAsyncIOTransport(FirewallTransport):
             self._stubs["delete_ingress_rule"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.Firewall/DeleteIngressRule",
                 request_serializer=appengine.DeleteIngressRuleRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_ingress_rule"]
 
