@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,23 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Callable, Dict, Optional, Sequence, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import grpc_helpers  # type: ignore
 from google.api_core import operations_v1  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import service
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import ServicesTransport, DEFAULT_CLIENT_INFO
 
 
@@ -53,7 +50,7 @@ class ServicesGrpcTransport(ServicesTransport):
         self,
         *,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
@@ -67,7 +64,8 @@ class ServicesGrpcTransport(ServicesTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -178,7 +176,7 @@ class ServicesGrpcTransport(ServicesTransport):
     def create_channel(
         cls,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -209,13 +207,15 @@ class ServicesGrpcTransport(ServicesTransport):
             google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -293,7 +293,7 @@ class ServicesGrpcTransport(ServicesTransport):
     @property
     def update_service(
         self,
-    ) -> Callable[[appengine.UpdateServiceRequest], operations.Operation]:
+    ) -> Callable[[appengine.UpdateServiceRequest], operations_pb2.Operation]:
         r"""Return a callable for the update service method over gRPC.
 
         Updates the configuration of the specified service.
@@ -312,14 +312,14 @@ class ServicesGrpcTransport(ServicesTransport):
             self._stubs["update_service"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.Services/UpdateService",
                 request_serializer=appengine.UpdateServiceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["update_service"]
 
     @property
     def delete_service(
         self,
-    ) -> Callable[[appengine.DeleteServiceRequest], operations.Operation]:
+    ) -> Callable[[appengine.DeleteServiceRequest], operations_pb2.Operation]:
         r"""Return a callable for the delete service method over gRPC.
 
         Deletes the specified service and all enclosed
@@ -339,7 +339,7 @@ class ServicesGrpcTransport(ServicesTransport):
             self._stubs["delete_service"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.Services/DeleteService",
                 request_serializer=appengine.DeleteServiceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_service"]
 
